NeuroImaging workflows (NiWorkflows): robust processing tools for MRI data
==========================================================================

.. image:: https://circleci.com/gh/nipreps/niworkflows/tree/master.svg?style=shield
  :target: https://circleci.com/gh/nipreps/niworkflows/tree/master
  :alt: CI status

.. image:: https://github.com/nipreps/niworkflows/workflows/Python%20package/badge.svg
  :target: https://github.com/nipreps/niworkflows/actions
  :alt: GitHub Actions

.. image:: https://codecov.io/gh/nipreps/niworkflows/branch/master/graph/badge.svg
  :target: https://codecov.io/gh/nipreps/niworkflows
  :alt: Test coverage

*NeuroImaging Workflows (NiWorkflows)* is a selection of image processing workflows
for magnetic resonance images of the brain. It is designed to provide an easily
accessible, state-of-the-art interface that is robust to differences in scan
acquisition protocols and that requires minimal user input.

This open-source neuroimaging data processing tool is being developed as a part of
the MRI image analysis and reproducibility platform offered by the *NiPreps Community*.

**Documentation**: https://www.nipreps.org/niworkflows/
